@@ -223,7 +223,7 @@ class ObjectIdentity:
 
         Examples
         --------
-        >>> ObjectIdentity('SNMPv2-MIB', 'sysDescr').addAsn1Source('https://pysnmp.github.io:443/mibs/asn1/@mib@')
+        >>> ObjectIdentity('SNMPv2-MIB', 'sysDescr').addAsn1Source('https://mibs.pysnmp.com/asn1/@mib@')
         ObjectIdentity('SNMPv2-MIB', 'sysDescr')
         >>>
 
@@ -738,7 +738,7 @@ class ObjectType:
 
         Examples
         --------
-        >>> ObjectType(ObjectIdentity('SNMPv2-MIB', 'sysDescr')).addAsn1Source('https://pysnmp.github.io:443/mibs/asn1/@mib@')
+        >>> ObjectType(ObjectIdentity('SNMPv2-MIB', 'sysDescr')).addAsn1Source('https://mibs.pysnmp.com/asn1/@mib@')
         ObjectType(ObjectIdentity('SNMPv2-MIB', 'sysDescr'))
         >>>
 
@@ -1043,7 +1043,7 @@ class NotificationType:
 
         Examples
         --------
-        >>> NotificationType(ObjectIdentity('IF-MIB', 'linkDown'), (), {}).addAsn1Source('https://pysnmp.github.io:443/mibs/asn1/@mib@')
+        >>> NotificationType(ObjectIdentity('IF-MIB', 'linkDown'), (), {}).addAsn1Source('https://mibs.pysnmp.com/asn1/@mib@')
         NotificationType(ObjectIdentity('IF-MIB', 'linkDown'), (), {})
         >>>
 
